package io.swagger.api;

import io.swagger.model.ErrorObj;
import io.swagger.model.NwsWarningsOnpointObj;

import java.io.InputStream;
import java.io.OutputStream;
import java.util.List;
import java.util.Map;
import javax.ws.rs.*;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.MediaType;
import org.apache.cxf.jaxrs.ext.multipart.*;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.responses.ApiResponses;
import io.swagger.v3.oas.annotations.responses.ApiResponse;
import io.swagger.v3.oas.annotations.media.ArraySchema;
import io.swagger.v3.oas.annotations.media.Content;
import io.swagger.v3.oas.annotations.media.Schema;

/**
 * NWS Warnings - A Weather Source API
 *
 * <p>NWS advisories, watches and warnings for latitude/longitude points and OnPoint™ points. The Weather Source NWS Warnings API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.      **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.      When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 */
@Path("/")
public interface OnpointsApi  {

    /**
     * NWS advisories, watches and warnings for an OnPoint™ point.
     *
     * Returns NWS advisories, watches and warnings data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source NWS Warnings API, each request must contain your API key set to a custom header named &#x60;X-API-KEY&#x60;. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key &#x60;C0W60UOFRML47ytbXk4xlLBfv&#x60; to access example locations found in this documentation.  When using the \\\&quot;Try it out\\\&quot; capability in the documentation, the API key should be added by clicking the green \\\&quot;Authorize\\\&quot; button at the top of the page. 
     *
     */
    @GET
    @Path("/onpoints/{onpointId}")
    @Produces({ "application/json" })
    @Operation(summary = "NWS advisories, watches and warnings for an OnPoint™ point.", tags={  })
    @ApiResponses(value = { 
        @ApiResponse(responseCode = "200", description = "NWS Warnings response for an OnPoint™ point.", content = @Content(mediaType = "application/json", schema = @Schema(implementation = NwsWarningsOnpointObj.class))),
        @ApiResponse(responseCode = "200", description = "Unexpected error response", content = @Content(mediaType = "application/json", schema = @Schema(implementation = ErrorObj.class))) })
    public NwsWarningsOnpointObj onpointsOnpointIdGet(@PathParam("onpointId") Integer onpointId);
}
